summaryrefslogtreecommitdiffstats
path: root/qtsharp/src/examples/samples/qstring-slot.cs
diff options
context:
space:
mode:
Diffstat (limited to 'qtsharp/src/examples/samples/qstring-slot.cs')
-rw-r--r--qtsharp/src/examples/samples/qstring-slot.cs22
1 files changed, 11 insertions, 11 deletions
diff --git a/qtsharp/src/examples/samples/qstring-slot.cs b/qtsharp/src/examples/samples/qstring-slot.cs
index e33fa1b3..af2db0a2 100644
--- a/qtsharp/src/examples/samples/qstring-slot.cs
+++ b/qtsharp/src/examples/samples/qstring-slot.cs
@@ -1,26 +1,26 @@
// Demo of a TQString slot
// Implemented by Marcus Urban
using System;
using Qt;
-public class MyWidget : QVBox
+public class MyWidget : TQVBox
{
- TQLineEdit lineEdit;
- TQLabel label;
+ TTQLineEdit lineEdit;
+ TTQLabel label;
- public MyWidget (TQWidget parent, String name) : base (parent, name)
+ public MyWidget (TTQWidget parent, String name) : base (parent, name)
{
- lineEdit = new TQLineEdit( this, "lineEdit" );
- label = new TQLabel( this, "label" );
+ lineEdit = new TTQLineEdit( this, "lineEdit" );
+ label = new TTQLabel( this, "label" );
label.SetText("Default");
- TQObject.Connect( lineEdit, TQT_SIGNAL("textChanged(TQString)"),
- label, "SetText(TQString)" );
+ TTQObject.Connect( lineEdit, TQT_SIGNAL("textChanged(TTQString)"),
+ label, "SetText(TTQString)" );
}
- public MyWidget (TQWidget parent) : this (parent, "") {}
+ public MyWidget (TTQWidget parent) : this (parent, "") {}
public MyWidget () : this (null, "") {}
}
@@ -28,7 +28,7 @@ public class Example {
public static int Main (String[] args)
{
- TQApplication a = new TQApplication (args);
+ TTQApplication a = new TTQApplication (args);
MyWidget w = new MyWidget ();
a.SetMainWidget (w);
@@ -1,26 +1,26 @@
-// Demo of a TQString slot
+// Demo of a TTQString slot
// Implemented by Marcus Urban
using System;